summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/keditparametric.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/keditparametric.h')
-rw-r--r--kmplot/kmplot/keditparametric.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/kmplot/kmplot/keditparametric.h b/kmplot/kmplot/keditparametric.h
index 334d997a..10a69dec 100644
--- a/kmplot/kmplot/keditparametric.h
+++ b/kmplot/kmplot/keditparametric.h
@@ -36,11 +36,12 @@ class XParser;
class KEditParametric : public QEditParametric
{
Q_OBJECT
+ TQ_OBJECT
public:
/// @param parser points to the parser instance.
/// @param parent points to the parent widget.
/// @param name of this instance.
- KEditParametric( XParser* parser, TQWidget* parent = NULL, const char* name = NULL );
+ KEditParametric( XParser* parser, TQWidget* tqparent = NULL, const char* name = NULL );
/// Nothing special to do.
virtual ~KEditParametric() {}
@@ -75,6 +76,7 @@ class KEditParametric : public QEditParametric
void customMaxRange_toggled(bool);
void customMinRange_toggled(bool);
+ protected:
Ufkt *m_updatedfunction;
};
@@ -36,11 +36,12 @@ class XParser;
public:
/// @param parser points to the parser instance.
- /// @param parent points to the parent widget.
+ /// @param tqparent points to the tqparent widget.
/// @param name of this instance.